translate.lang.ug.ug

Package translate :: Package lang :: Module ug :: Class ug |
[hide private]
[frames] | no frames]

# Class ug

source code

This class represents Uyghur.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `common.Common`: `alter_length`, `capsstart`, `character_iter`, `characters`, `length_difference`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| listseperator = ``u'``،` `'`` This string is used to separate lists of textual elements.
| puncdict = ``{``u'``,``'``:` `u'``،``'``,` `u'``;``'``:` `u'``؛``'``,` `u'``?``'``:` `u'``؟``'``}`` A dictionary of punctuation transformation rules that can be used by punctranslate().
| ignoretests = ``[``'``startcaps``'``,` `'``simplecaps``'``]`` List of pofilter tests for this language that must be ignored.
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `indicpunc`, `invertedpunc`, `miscpunc`, `nplurals`, `pluralequation`, `punctuation`, `quotes`, `rtlpunc`, `sentenceend`, `sentencere`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`